/*
 * Jalview - A Sequence Alignment Editor and Viewer ($$Version-Rel$$)
 * Copyright (C) $$Year-Rel$$ The Jalview Authors
 * 
 * This file is part of Jalview.
 * 
 * Jalview is free software: you can redistribute it and/or
 * modify it under the terms of the GNU General Public License 
 * as published by the Free Software Foundation, either version 3
 * of the License, or (at your option) any later version.
 *  
 * Jalview is distributed in the hope that it will be useful, but 
 * WITHOUT ANY WARRANTY; without even the implied warranty 
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
 * PURPOSE.  See the GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Jalview.  If not, see <http://www.gnu.org/licenses/>.
 * The Jalview Authors are detailed in the 'AUTHORS' file.
 */
package jalview.ext.archaeopteryx;

import jalview.datamodel.SequenceI;
import jalview.structure.SelectionListener;
import jalview.structure.SelectionSource;

import java.awt.event.ActionListener;
import java.awt.event.MouseEvent;
import java.awt.event.MouseListener;

/**
 * 
 * Interface for binding a tree viewer to Jalview alignments. Assumes a tree
 * viewer will both want to receive and send selection events.
 * 
 * @author kjvanderheide
 *
 * @param <N>
 *          Tree node object.
 */
interface ExternalTreeViewerBindingI<N>
        extends ActionListener, MouseListener, SelectionListener,
        SelectionSource
{
  /**
   * If a node is selected in the tree panel this method highlights the
   * corresponding sequence in the Jalview alignment view. If an internal node
   * is selected all child sequences get highlighted as well.
   */
  public void showNodeSelectionOnAlign(MouseEvent e);

  public void treeSelectionChanged(SequenceI sequence);

  public void showMatchingSequence(N nodeToMatch);

  public void showMatchingChildSequences(N parentNode);

}
